@@ -1,6 +1,6 @@
 from typing import Type, Union, Text, List, get_args, get_origin, Any
 from sqlalchemy.sql.sqltypes import NullType, DateTime, Float, JSON, Integer, String
-from .uttil import Datetime
+from .util import Datetime
 from dataclasses import dataclass, is_dataclass, fields, Field, field
 from sqlalchemy.types import TypeEngine
 
